<?php

namespace Drupal\changelog_preview\Controller;

use Drupal\Core\Controller\ControllerBase;
use Michelf\Markdown;

/**
 * This class is representing the changelog.
 */
class ChangelogPreviewController extends ControllerBase {

  /**
   * Display the markup.
   *
   * @return array
   *   Return markup array.name
   */
  public function content() {
    $parser  = new Markdown();
    $context = $this->t('Nothing to show here.');

    $route_name = \Drupal::routeMatch()->getRouteName();

    $matches = explode('.', $route_name);

    if (isset($matches[1])) {
      $configuration = \Drupal::config('changelog_preview.changelog_manage_form');
      $file_path     = \Drupal::root() . $configuration->get('changelog_file_path_' . $matches[1]) ?? '';

      if (@file_exists($file_path)) {
        $context = $parser->transform(file_get_contents($file_path));
      }
    }

    return [
      '#type' => 'markup',
      '#markup' => $context,
    ];
  }

  /**
   * List all the changelogs.
   *
   * @return array
   *   Get all the changelogs to list on page.
   */
  public function listChangelogs() {
    $config = \Drupal::config('changelog_preview.changelog_manage_form');
    $changelog_items_count = $config->get('changelog_items_count') ?? 0;

    if ($changelog_items_count == 0) {
      return [
        '#type' => 'markup',
        '#markup' => $this->t('No changelog items found.'),
      ];
    }

    $context = '';

    for ($key = 0; $key < $changelog_items_count; $key++) {
      $browser_path = $config->get('changelog_browser_path_' . $key);
      $title = $config->get('changelog_name_' . $key);
      $context .= "<br /><a href='$browser_path'>$title</a><br />";
    }

    return [
      '#type' => 'markup',
      '#markup' => $context,
    ];
  }

}
