<?php

namespace Drupal\changelog_preview\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines dynamic local tasks.
 */
class DynamicLocalTasks extends DeriverBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $derivatives = [];

    $configuration = \Drupal::config('changelog_preview.changelog_manage_form');
    $pathCount     = $configuration->get('changelog_items_count') ?? 0;

    $derivatives['changelog_base'] = $base_plugin_definition;
    $derivatives['changelog_base']['title'] = $this->t('Changelog');
    $derivatives['changelog_base']['route_name'] = 'changelog_preview.object';
    $derivatives['changelog_base']['base_route'] = 'changelog_preview.object';
    $derivatives['changelog_base']['weight'] = 100;

    try {
      for ($i = 0; $i < $pathCount; $i++) {
        $name = $configuration->get('changelog_name_' . $i) ?? '';

        /** @var \Drupal\Core\Routing\RouteProviderInterface $route_provider */
        $route_provider = \Drupal::service('router.route_provider');
        $route = $route_provider->getRouteByName('changelog.' . $i);

        if (!$route) {
          continue;
        }

        $derivatives['changelog_' . $i] = $base_plugin_definition;
        $derivatives['changelog_' . $i]['title'] = $this->t($name);
        $derivatives['changelog_' . $i]['route_name'] = 'changelog.' . $i;
        $derivatives['changelog_' . $i]['base_route'] = 'changelog_preview.object';
        $derivatives['changelog_' . $i]['weight'] = 100;
      }
    }
    catch (\Exception $e) {
      // Do nothing.
    }

    return $derivatives;
  }

}
